@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::Plugin::Run::AfterBuild;
 # ABSTRACT: execute a command of the distribution after build
 
-our $VERSION = '0.042';
+our $VERSION = '0.043';
 
 use Moose;
 with qw(
@@ -25,12 +25,12 @@ sub after_build {
 #pod =head1 SYNOPSIS
 #pod
 #pod   [Run::AfterBuild]
-#pod   run = script/do_this.pl --dir %s --version %s
+#pod   run = script/do_this.pl --dir %d --version %v
 #pod   run = script/do_that.pl
 #pod
 #pod =head1 DESCRIPTION
 #pod
-#pod This plugin executes the specified command after building the dist.
+#pod This plugin executes the specified command after building the distribution.
 #pod
 #pod =head1 POSITIONAL PARAMETERS
 #pod
@@ -40,8 +40,8 @@ sub after_build {
 #pod For backward compatibility:
 #pod
 #pod =for :list
-#pod * The 1st C<%s> will be replaced by the directory in which the dist was built.
-#pod * The 2nd C<%s> will be replaced by the dist version.
+#pod * The 1st C<%s> will be replaced by the directory in which the distribution was built.
+#pod * The 2nd C<%s> will be replaced by the distribution version.
 #pod
 #pod =cut
 
@@ -59,17 +59,17 @@ Dist::Zilla::Plugin::Run::AfterBuild - execute a command of the distribution aft
 
 =head1 VERSION
 
-version 0.042
+version 0.043
 
 =head1 SYNOPSIS
 
   [Run::AfterBuild]
-  run = script/do_this.pl --dir %s --version %s
+  run = script/do_this.pl --dir %d --version %v
   run = script/do_that.pl
 
 =head1 DESCRIPTION
 
-This plugin executes the specified command after building the dist.
+This plugin executes the specified command after building the distribution.
 
 =head1 POSITIONAL PARAMETERS
 
@@ -82,19 +82,30 @@ For backward compatibility:
 
 =item *
 
-The 1st C<%s> will be replaced by the directory in which the dist was built.
+The 1st C<%s> will be replaced by the directory in which the distribution was built.
 
 =item *
 
-The 2nd C<%s> will be replaced by the dist version.
+The 2nd C<%s> will be replaced by the distribution version.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Run>
+(or L<bug-Dist-Zilla-Plugin-Run@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Run@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
 =head1 AUTHOR
 
 Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2010 by L<Raudssus Social Software|https://raudss.us/>.
 
